==> hyperstream-0.2.6.tar.gz: hyperstream-0.2.6/hyperstream/channels/tool_channel.py <==
# The MIT License (MIT) # Copyright (c) 2014-2017 University of Bristol
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
#  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
#  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
#  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
#  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
#  OR OTHER DEALINGS IN THE SOFTWARE.

from module_channel import ModuleChannel
from ..stream import StreamInstance


class ToolChannel(ModuleChannel):
    """
    Special case of the file/module channel to load the tools to execute other streams
    """
    def get_results(self, stream, time_interval):
        results = super(ToolChannel, self).get_results(stream, time_interval)
        for timestamp, (version, module_importer) in results:
            module = module_importer()
            class_name = stream.stream_id.name.title().replace("_", "")
            tool_class = getattr(module, class_name)
            yield StreamInstance(timestamp, tool_class)

==> hyperstream-0.3.4.tar.gz: hyperstream-0.3.4/hyperstream/channels/tool_channel.py <==
# The MIT License (MIT) # Copyright (c) 2014-2017 University of Bristol
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
#  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
#  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
#  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
#  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
#  OR OTHER DEALINGS IN THE SOFTWARE.

from .module_channel import ModuleChannel
from ..stream import StreamInstance


class ToolChannel(ModuleChannel):
    """
    Special case of the file/module channel to load the tools to execute other streams
    """
    def get_results(self, stream, time_interval):
        results = super(ToolChannel, self).get_results(stream, time_interval)
        if results:
            for timestamp, (version, module_importer) in results:
                module = module_importer()
                class_name = stream.stream_id.name.title().replace("_", "")
                tool_class = getattr(module, class_name)
                yield StreamInstance(timestamp, tool_class)
        else:
            yield None
